import java.util.regex.Pattern;



/**
 * Entity class for business divisions.
 */
public class BusinessDivision extends ManualIdentifier {

	// --------------------------------------------------------- Static Fields

	/** Length of business division name. */
	public static final int LENGTH_BUSINESS_DIV_NAME = 2;

	/** Regular expression for valid identifiers. */
	public static final Pattern IDENTIFIER_PATTERN = Pattern
			.compile("^[A-Z]{2}$");

	/** Version for serialization. */
	private static final long serialVersionUID = -3971208754678719996L;

	// ------------------------------------------------------- Instance Fields

	private String name;

	private String description;

	private String prefixEvaMaterialNo;

	private String defaultKName;

	private String distributionChannel;

	// ---------------------------------------------------------- Constructors

	/**
	 * Default constructor according to the Java Beans specification. Should
	 * only be used by mapping frameworks, not by the application itself.
	 * 
	 * @deprecated Use the constructor with the identifier parameter instead
	 */
	@Deprecated
	public BusinessDivision() {
		super();
	}

	/**
	 * Create a new entity with the given identifier.
	 * 
	 * @param identifier
	 *            The immutable identifier.
	 * @throws IllegalArgumentException
	 *             if the identifier is invalid
	 */
	public BusinessDivision(final String identifier) {
		name = checkIdentifier(identifier);
	}

	// -------------------------------------------------------- Public Methods

	/**
	 * Check if a given string is a valid identifier and optionally simplify
	 * (for example remove spaces or convert the case) it.
	 * 
	 * @param identifier
	 *            The identifier to check
	 * @return the simplified identifier
	 * @throws IllegalArgumentException
	 *             if the identifier is not valid
	 */
	public static String checkIdentifier(final String identifier) {
		if (!IDENTIFIER_PATTERN.matcher(identifier).matches()) {
			throw new IllegalArgumentException("Invalid identifier: "
					+ identifier);
		}
		return identifier;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String getId() {
		return name;
	}

	// ----------------------------------- Generated Getter and Setter Methods

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getDefaultKName() {
		return defaultKName;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param defaultKName
	 *            the property to set
	 */
	public void setDefaultKName(String defaultKName) {
		this.defaultKName = defaultKName;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getDescription() {
		return description;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param description
	 *            the property to set
	 */
	public void setDescription(String description) {
		this.description = description;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 * 
	 * @return the requested property
	 */
	public String getDistributionChannel() {
		return distributionChannel;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param distributionChannel
	 *            the property to set
	 */
	public void setDistributionChannel(String distributionChannel) {
		this.distributionChannel = distributionChannel;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getName() {
		return name;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param name
	 *            the property to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getPrefixEvaMaterialNo() {
		return prefixEvaMaterialNo;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param prefixEvaMaterialNo
	 *            the property to set
	 */
	public void setPrefixEvaMaterialNo(String prefixEvaMaterialNo) {
		this.prefixEvaMaterialNo = prefixEvaMaterialNo;
	}

	// ----------------------------------------------------- Protected Methods

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected boolean equalsClass(Object o) {
		return o instanceof BusinessDivision;
	}
}
