import java.util.regex.Pattern;


/**
 * Entity class for a commodity code ("Statistische Warennummer").
 */
public class CommodityCode extends GeneratedIdentifier {

	// --------------------------------------------------------- Static Fields

	/** Regular expression for valid commodity code. */
	public static final Pattern COMMODITYCODE_PATTERN = Pattern.compile("^[0-9]{8,10}$");

	/** Length of commodity code. */
	public static final int LENGTH_COMMODITY_CODE = 10;

	/** Version for serialization. */
	private static final long serialVersionUID = 19663136563752291L;

	// ------------------------------------------------------- Instance Fields

	/** Commodity code, either a prefix or fully specified. */
	private String commodityCode;

	private BusinessDivision businessDivision;

	private String englishDescription;

	private String germanDescription;

	// -------------------------------------------------------- Public Methods

	/**
	 * Check if a given string is a valid identifier and optionally simplify
	 * (for example remove spaces or convert the case) it.
	 * 
	 * @param commodityCode
	 *            The commodityCode to check
	 * @return the simplified commodityCode
	 * @throws IllegalArgumentException
	 *             if the commodityCode is not valid
	 */
	public static String checkCommodityCode(final String commodityCode) {
		if (!COMMODITYCODE_PATTERN.matcher(commodityCode).matches()) {
			throw new IllegalArgumentException("Invalid commodityCode: "
					+ commodityCode);
		}
		return commodityCode;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		return commodityCode;
	}

	// ----------------------------------- Generated Getter and Setter Methods

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public BusinessDivision getBusinessDivision() {
		return businessDivision;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param businessDivision
	 *            the property to set
	 */
	public void setBusinessDivision(BusinessDivision businessDivision) {
		this.businessDivision = businessDivision;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getCommodityCode() {
		return commodityCode;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param commodityCode
	 *            the property to set
	 */
	public void setCommodityCode(String commodityCode) {
		this.commodityCode = commodityCode;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getEnglishDescription() {
		return englishDescription;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param englishDescription
	 *            the property to set
	 */
	public void setEnglishDescription(String englishDescription) {
		this.englishDescription = englishDescription;
	}

	/**
	 * Generated getter method which just returns the property without
	 * additional processing.
	 *
	 * @return the requested property
	 */
	public String getGermanDescription() {
		return germanDescription;
	}

	/**
	 * Generated setter method which just sets the property without additional
	 * processing.
	 * 
	 * @param germanDescription
	 *            the property to set
	 */
	public void setGermanDescription(String germanDescription) {
		this.germanDescription = germanDescription;
	}
}
