import java.io.Serializable;

/**
 * Base class for persistent model objects which have their identifier assigned
 * by the data base. The identifier is stored as a <code>Long</code>.
 */
public abstract class GeneratedIdentifier extends PersistentEntity {

	// --------------------------------------------------------- Static Fields

	/** Version for serialization. */
	private static final long serialVersionUID = 1L;

	// ------------------------------------------------------- Instance Fields

	/** The generated identifier. */
	private Long generatedId;

	// --------------------------------------------------------- Public Methods

	/**
	 * Returns the generated identifier of this entity.
	 * 
	 * @return the generated identifier
	 */
	public Long getGeneratedId() {
		return generatedId;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Serializable getId() {
		if (generatedId != null) {
			return generatedId.toString();
		}
		return null;
	}

	/**
	 * {@inheritDoc}
	 */
	public int compareTo(PersistentEntity o) {
		return toString().compareTo(o.toString());
	}
}
