
import java.sql.Types;

import org.hibernate.dialect.Oracle10gDialect;
import org.hibernate.type.StandardBasicTypes;

/**
 * Hibernate dialect for Oracle 10g which uses <code>nvarchar2</code> instead of
 * <code>varchar2</code> for strings.
 */
public final class Oracle10nDialect extends Oracle10gDialect {

	// --------------------------------------------------------- Static Fields

	/** Maximum length of strings which should be mapped to nvarchar2. */
	private static final int MAX_VARCHAR_LENTH = 4000;

	// ---------------------------------------------------------- Constructors

	/**
	 * Create a new instance with the mapping to strings.
	 */
	public Oracle10nDialect() {
		super();
		registerColumnType(Types.VARCHAR, MAX_VARCHAR_LENTH, "nvarchar2($l)");
		// no need to use 1 char for boolean, use 1 byte instead
		registerColumnType(Types.CHAR, "char(1)");
		registerHibernateType(Types.NVARCHAR, StandardBasicTypes.STRING.getName());
	}
}
